@@ -336,25 +336,24 @@ pub fn process_audio_loop(
                     // There's enough buffered input data to run a round of FFT
                     // Copy input_len values from audio_buf to fft_buf, applying hann window along the way
                     // There's a little extra complexity here because the ringbuf exposes the content as two parts
-                    audio_buf_out.access(|older, newer| {
-                        if older.len() >= input_len {
-                            // just read from older
-                            for i in 0..input_len {
-                                fft_buf[i] = Complex::new(input_window_scales[i] * older[i], 0.0);
-                            }
-                        } else {
-                            // read from older, then newer
-                            for idx in 0..older.len() {
-                                fft_buf[idx] =
-                                    Complex::new(input_window_scales[idx] * older[idx], 0.0);
-                            }
-                            for i in 0..(input_len - older.len()) {
-                                let buf_idx = older.len() + i;
-                                fft_buf[buf_idx] =
-                                    Complex::new(input_window_scales[buf_idx] * newer[i], 0.0);
-                            }
+                    let (older_audio, newer_audio) = audio_buf_out.as_slices();
+                    if older_audio.len() >= input_len {
+                        // just read from older_audio
+                        for i in 0..input_len {
+                            fft_buf[i] = Complex::new(input_window_scales[i] * older_audio[i], 0.0);
                         }
-                    });
+                    } else {
+                        // read from older_audio, then newer_audio
+                        for idx in 0..older_audio.len() {
+                            fft_buf[idx] =
+                                Complex::new(input_window_scales[idx] * older_audio[idx], 0.0);
+                        }
+                        for i in 0..(input_len - older_audio.len()) {
+                            let buf_idx = older_audio.len() + i;
+                            fft_buf[buf_idx] =
+                                Complex::new(input_window_scales[buf_idx] * newer_audio[i], 0.0);
+                        }
+                    }
 
                     // Remove the first HALF of the values from audio_buf, shifting it forward.
                     // The second half is left in-place.
