@@ -126,12 +126,12 @@ struct SizedState {
     // The number of logical rows in analyzer_buf.
     analyzer_height: usize,
     // The analyzer RGBA value data, which is only updated once per batch of inputs.
-    analyzer_buf: Vec<u8>,
+    analyzer_buf: Vec<u32>,
 
     // The number of logical rows in voiceprint_buf.
     voiceprint_height: usize,
     // The voiceprint RGBA value data, acts as a ring buffer where voiceprint_row is input offset.
-    voiceprint_buf: Vec<u8>,
+    voiceprint_buf: Vec<u32>,
     // The "active" row to update in voiceprint_buf.
     voiceprint_row: usize,
 }
@@ -350,6 +350,16 @@ impl State {
             recv_processed_size,
         );
 
+        let config = wgpu::SurfaceConfiguration {
+            usage: wgpu::TextureUsages::RENDER_ATTACHMENT,
+            format: config_format,
+            width: window_size.width,
+            height: window_size.height,
+            present_mode: wgpu::PresentMode::Fifo,
+        };
+        // Call configure() once up-front, needed for tiling WMs like sway
+        surface.configure(&device, &config);
+
         State {
             scroll_rate,
 
@@ -360,13 +370,7 @@ impl State {
             bind_group_layout,
             index_buffer,
 
-            config: wgpu::SurfaceConfiguration {
-                usage: wgpu::TextureUsages::RENDER_ATTACHMENT,
-                format: config_format,
-                width: window_size.width,
-                height: window_size.height,
-                present_mode: wgpu::PresentMode::Fifo,
-            },
+            config,
             orientation,
             sized_state,
 
@@ -469,8 +473,8 @@ impl State {
         // Iterate over the batch. only render analyzer on the last entry of the batch
         for (audio_idx, audio) in audio_vec.iter().enumerate() {
             // Set to buffer index for the start of the current row in voiceprint_buf
-            // 4 (RGBA pixel size) * row index in voiceprint_buf * width of voiceprint_buf
-            let mut voiceprint_idx = 4 * self.sized_state.voiceprint_row * self.recv_processed_size;
+            // row index in voiceprint_buf * width of voiceprint_buf
+            let mut voiceprint_idx = self.sized_state.voiceprint_row * self.recv_processed_size;
 
             // Iterator contains frequency data from low to high frequency
             let mut audio_iter = audio.into_iter();
@@ -479,11 +483,11 @@ impl State {
                 // We're at the last entry of the batch (common case unless we're falling behind).
                 // Render both the voiceprint and the analyzer.
                 let mut analyzer_idx = 0;
-                // analyzer: reset to black, to redraw with lines below
+                // analyzer: Reset to opaque black (r=0,g=0,b=0,a=255)
                 self.sized_state.analyzer_buf.clear();
                 self.sized_state
                     .analyzer_buf
-                    .resize(self.sized_state.analyzer_buf.capacity(), 0);
+                    .resize(self.sized_state.analyzer_buf.capacity(), 255 * 16777216);
 
                 for _ in 0..self.recv_processed_4x_size {
                     // Draw low frequencies as 4x zoom
@@ -546,8 +550,9 @@ impl State {
                 mip_level: 0,
                 origin: wgpu::Origin3d::ZERO,
             },
-            &self.sized_state.voiceprint_buf,
+            as_u8_slice(&self.sized_state.voiceprint_buf),
             wgpu::ImageDataLayout {
+                // 4x values to get byte offsets (rather than u32 offsets)
                 offset: (self.sized_state.voiceprint_row * 4 * self.recv_processed_size) as u64,
                 bytes_per_row: NonZeroU32::new(4 * self.recv_processed_size as u32),
                 rows_per_image: NonZeroU32::new(self.sized_state.voiceprint_height as u32),
@@ -573,8 +578,9 @@ impl State {
                     z: 0,
                 },
             },
-            &self.sized_state.voiceprint_buf,
+            as_u8_slice(&self.sized_state.voiceprint_buf),
             wgpu::ImageDataLayout {
+                // 4x values to get byte offsets (rather than u32 offsets)
                 offset: 0,
                 bytes_per_row: NonZeroU32::new(4 * self.recv_processed_size as u32),
                 rows_per_image: NonZeroU32::new(self.sized_state.voiceprint_row as u32),
@@ -598,8 +604,9 @@ impl State {
                     z: 0,
                 },
             },
-            &self.sized_state.analyzer_buf,
+            as_u8_slice(&self.sized_state.analyzer_buf),
             wgpu::ImageDataLayout {
+                // 4x values to get byte offsets (rather than u32 offsets)
                 offset: 0,
                 bytes_per_row: NonZeroU32::new(4 * self.recv_processed_size as u32),
                 rows_per_image: NonZeroU32::new(self.sized_state.analyzer_height as u32),
@@ -662,8 +669,8 @@ impl State {
         // Repeat the value N times to zoom in on lower frequencies.
         for _ in 0..times {
             // voiceprint: draw rgba pixel on row
-            update_pixel(&mut self.sized_state.voiceprint_buf, *voiceprint_idx, pixel);
-            (*voiceprint_idx) += 4; // seek to next rgba pixel on row
+            self.sized_state.voiceprint_buf[*voiceprint_idx] = pixel;
+            (*voiceprint_idx) += 1; // seek to next rgba pixel on row
         }
     }
 
@@ -685,26 +692,28 @@ impl State {
         // Repeat the value N times to zoom in on lower frequencies.
         for _ in 0..times {
             // voiceprint: draw rgba pixel on row
-            update_pixel(&mut self.sized_state.voiceprint_buf, *voiceprint_idx, pixel);
-            (*voiceprint_idx) += 4; // seek to next rgba pixel on row
+            self.sized_state.voiceprint_buf[*voiceprint_idx] = pixel;
+            (*voiceprint_idx) += 1; // seek to next rgba pixel on row
 
             // analyzer: draw vertical rgba line on single column (rotated to horizontal later)
             let mut col_idx = *analyzer_idx; // top of column
             for _pixel_col in 0..bar_width {
-                update_pixel(&mut self.sized_state.analyzer_buf, col_idx, pixel);
-                col_idx += 4 * self.recv_processed_size; // next row in column
+                self.sized_state.analyzer_buf[col_idx] = pixel;
+                col_idx += self.recv_processed_size; // next row in column
             }
-            (*analyzer_idx) += 4; // seek to next col to draw another vertical line
+            (*analyzer_idx) += 1; // seek to next col to draw another vertical line
         }
     }
 }
 
-/// Applies an RGBA value to the provided vec.
-fn update_pixel(v: &mut Vec<u8>, idx: usize, pixel: &[u8; 4]) {
-    v[idx] = pixel[0];
-    v[idx + 1] = pixel[1];
-    v[idx + 2] = pixel[2];
-    v[idx + 3] = pixel[3];
+/// Recasts a &[u32] as a &[u8] for passing to gfx
+fn as_u8_slice(v: &[u32]) -> &[u8] {
+    unsafe {
+        std::slice::from_raw_parts(
+            v.as_ptr() as *const u8,
+            v.len() * std::mem::size_of::<u32>(),
+        )
+    }
 }
 
 /// (Re)initializes the render state to reflect a change in window size.
@@ -787,13 +796,15 @@ fn init_sized_state(
 
     // Circular voiceprint buffer written to top 80% of texture
     let voiceprint_height = (0.8 * (texture_height as f32)) as usize;
-    let mut voiceprint_buf = Vec::with_capacity(4 * voiceprint_height * recv_processed_size);
-    voiceprint_buf.resize(voiceprint_buf.capacity(), 0);
+    let mut voiceprint_buf = Vec::with_capacity(voiceprint_height * recv_processed_size);
+    // Ensure the buffer is opaque black rather than transparent (r=0,g=0,b=0,a=255)
+    voiceprint_buf.resize(voiceprint_buf.capacity(), 255 * 16777216);
 
     // Analyzer written to bottom 20% of texture
     let analyzer_height = texture_height as usize - voiceprint_height;
-    let mut analyzer_buf = Vec::with_capacity(4 * analyzer_height * recv_processed_size);
-    analyzer_buf.resize(analyzer_buf.capacity(), 0);
+    let mut analyzer_buf = Vec::with_capacity(analyzer_height * recv_processed_size);
+    // Ensure the buffer is opaque black rather than transparent (r=0,g=0,b=0,a=255)
+    analyzer_buf.resize(analyzer_buf.capacity(), 255 * 16777216);
 
     SizedState {
         vertex_buffer,
